@@ -1502,6 +1502,8 @@ sub _handle_diff_provides {
 		    $_->obsoletes_overlap($p->name . " == " . $p->epoch . ":" . $p->version . "-" . $p->release))
 		   && (!strict_arch($urpm) || strict_arch_check($p, $_));
 	     } @packages;
+	#- don't promote an obsolete package (mga#23223)
+	@packages = grep { _find_packages_obsoleting($urpm, $state, $_) == 0 } @packages;
 
 	if (!@packages) {
 	    @packages = _find_packages_obsoleting($urpm, $state, $p);
@@ -1559,6 +1561,8 @@ sub _handle_conflict {
       $p->version . "-" . $p->release;
     my @packages = grep { $_->name eq $p->name } find_candidate_packages($urpm, $need_deps, $state->{rejected});
     @packages = grep { ! $_->provides_overlap($property) } @packages;
+    #- don't promote an obsolete package (mga#23223)
+    @packages = grep { _find_packages_obsoleting($urpm, $state, $_) == 0 } @packages;
 
     if (!@packages) {
 	@packages = _find_packages_obsoleting($urpm, $state, $p);
